@@ -18,8 +18,9 @@ function(x, norm = NULL){
   rotat <- tFOBIRotate(x, norm)
   x <- rotat$x
   
-  W <- list()
-  for(i in 1:length(stand$S)){
+  r <- length(stand$S)
+  W <- vector("list", r)
+  for(i in 1:r){
     W[[i]] <- rotat$U[[i]]%*%stand$S[[i]]
   }
   
